<?php
//plugins activator
require_once("plugins_activator.php");
//for is_plugin_active
include_once( ABSPATH . 'wp-admin/includes/plugin.php');
//theme options
require_once("theme-options.php");

//contact form options
require_once("contact-form-options.php");

//custom meta box
require_once("meta-box.php");

//comments
require_once("comments-functions.php");

//admin functions
require_once("admin/functions.php");

//Make theme available for translation
//Translations can be filed in the /languages/ directory
load_theme_textdomain('cascade', get_template_directory() . '/languages');

//register sidebars
function ca_widgets_init()
{
	register_sidebar(array(
		"id" => "sidebar-footer",
		"name" => __("Footer Sidebar", 'cascade'),
		"before_widget" => "<div id='sidebar-footer' class='cascade_clearfix'>",
		"after_widget" => "</div>"
	));
	register_sidebar(array(
		"id" => "sidebar-blog",
		"name" => __("Blog Sidebar", 'cascade'),
		"before_widget" => "<div id='sidebar-blog' class='cascade_clearfix'>",
		"after_widget" => "</div>"
	));
}

//register blog post thumbnail & portfolio thumbnail
add_theme_support("post-thumbnails");
add_image_size("blog-post-thumb", 195, 128, true);
add_image_size("blog-widget-post-thumb", 385, 128, true);
add_image_size("cascade-portfolio-thumb", 197, 130, true);
function cascade_image_sizes($sizes)
{
	$addsizes = array(
		"blog-post-thumb" => __("Blog post thumbnail", 'cascade'),
		"blog-widget-post-thumb" => __("Blog & widget area post thumbnail", 'cascade'),
		"cascade-portfolio-thumb" => __("Cascade portfolio thumbnail", 'cascade')
	);
	$newsizes = array_merge($sizes, $addsizes);
	return $newsizes;
}
add_filter("image_size_names_choose", "cascade_image_sizes");

//excerpt
function cascade_excerpt_more($more) 
{
	return '';
}
add_filter('excerpt_more', 'cascade_excerpt_more', 99);
	
//shortcodes
require_once("shortcodes.php");

function cascade_after_setup_theme()
{
	if(!get_option("cascade_installed"))
	{		
		//set custom permalinks
		//global $wp_rewrite;
		//$wp_rewrite->set_permalink_structure("#/%post_id%/%postname%");
		
		$cascade_options = array(
			"main_header" => __("Anna Brown", 'cascade'),
			"sub_header" => __("professional photographer & web developer", 'cascade'),
			"header_url" => "#!/main",
			"download_icon" => sprintf(__('<a href="%s" rel="nofollow" target="_blank">Download my vCard</a>', 'cascade'), esc_url(__('https://1.envato.market/cascade-one-page-resume-template', 'cascade'))),
			"phone_icon" => __("1.800.353.252", 'cascade'),
			"email_icon" => __('<a href="#">anna.brown@mail.com</a>', 'cascade'),
			"twitter_login" => "quanticalabs",
			"twitts_number" => 5,
			"icons" => array(
				"type" => array(	
					"rss",
					"facebook",
					"twitter",
					"google",
					"skype"
				),
				"value" => array(
					"http://themeforest.net/feeds/users/QuanticaLabs.atom",
					"#",
					"http://twitter.com/QuanticaLabs",
					"#",
					"#"
				)
			),
			"skin" => "dark",
			"top_bar" => "1",
			"animation_type" => "expand",
			"background" => "carbon",
			"background_map" => "",
			"footer_sidebar" => "widgets_and_cascade",
			"ajax" => 1,
			"google_api_code" => ""
		);
		add_option("cascade_options", $cascade_options);
		
		$cascade_contact_form_options = array(
			"name_hint" => __("Your Name", 'cascade'),
			"email_hint" => __("Your E-mail Address", 'cascade'),
			"text_hint" => __("Message", 'cascade'),
			"email_subject" => __("Cascade: Contact from WWW", 'cascade'),
			"admin_name" => get_option("admin_email"),
			"admin_email" => get_option("admin_email"),
			"template" => "<html>
	<head>
	</head>
	<body>
		<div><b>Name</b>: [name]</div>
		<div><b>E-mail</b>: [email]</div>
		<div><b>Message</b>: [message]</div>
	</body>
</html>",
			"smtp_host" => "",
			"smtp_username" => "",
			"smtp_password" => "",
			"smtp_port" => "",
			"smtp_secure" => "",
			"name_error" => __("Please enter your name.", 'cascade'),
			"email_error" => __("Please enter valid e-mail.", 'cascade'),
			"text_error" => __("Please enter your message.", 'cascade'),
			"message_send_error" => __("Sorry, we can\'t send this message.", 'cascade'),
			"message_send_ok" => __("Thank you for contacting us.", 'cascade')
		);
		add_option("cascade_contact_form_options", $cascade_contact_form_options);
		
		update_option("blogdescription", "Personal vCard WordPress Theme");
		
		add_option("cascade_installed", 1);
	}
	//enable custom background
	add_theme_support("custom-background"); //3.4
	//enable feed links
	add_theme_support("automatic-feed-links");
	//title tag
	add_theme_support("title-tag");
	//gutenberg
	add_theme_support("wp-block-styles");
	//register menus
	if(function_exists("register_nav_menu"))
	{
		register_nav_menu("cascade-header-top", "Header Menu Top");
		register_nav_menu("cascade-header-bottom", "Header Menu Bottom");
	}
	//phpMailer
	add_action('phpmailer_init', 'ca_phpmailer_init');
	//widgets
	if(function_exists("register_sidebar"))
	{
		add_action('widgets_init', 'ca_widgets_init');
	}
	//content width
	if(!isset($content_width)) 
		$content_width = 630;
	//custom theme filters
	add_filter('document_title_parts', 'ca_document_title_parts');
	add_filter('document_title_separator', 'ca_document_title_separator');
	//custom theme actions
	if(!function_exists('_wp_render_title_tag')) 
		add_action('wp_head', 'ca_theme_slug_render_title');
}
add_action("after_setup_theme", "cascade_after_setup_theme");

function cascade_switch_theme($theme_template)
{
	delete_option("cascade_installed");
}
add_action("switch_theme", "cascade_switch_theme");

/* --- phpMailer config --- */
function ca_phpmailer_init($mail) 
{
	global $cascade_contact_form_options;
	$mail->CharSet='UTF-8';

	$smtp = $cascade_contact_form_options["smtp_host"];
	if(!empty($smtp))
	{
		$mail->IsSMTP();
		$mail->SMTPAuth = true; 
		//$mail->SMTPDebug = 2;
		$mail->Host = $cascade_contact_form_options["smtp_host"];
		$mail->Username = $cascade_contact_form_options["smtp_username"];
		$mail->Password = $cascade_contact_form_options["smtp_password"];
		if((int)$cascade_contact_form_options["smtp_port"]>0)
			$mail->Port = (int)$cascade_contact_form_options["smtp_port"];
		$mail->SMTPSecure = $cascade_contact_form_options["smtp_secure"];
	}
}

if(!function_exists('_wp_render_title_tag')) 
{
    function ca_theme_slug_render_title() 
	{
		echo ''. wp_title('|', true, 'right') . '';
    }
}
function ca_document_title_parts($title_parts)
{
	$part1 = get_bloginfo('name');
	$part2 = (is_home() || is_front_page() || is_404() ? get_bloginfo('description') : $title_parts['title']);
	return array($part1, $part2);
}
function ca_document_title_separator($sep)
{
	$sep = "|";
    return $sep;
}

//theme options
global $cascade_options;
$cascade_options = array(
	"main_header" => '',
	"sub_header" => '',
	"header_url" => '',
	"download_icon" => '',
	"phone_icon" => '',
	"email_icon" => '',
	"twitter_login" => '',
	"twitts_number" => '',
	"consumer_key" => '',
	"consumer_secret" => '',
	"access_token" => '',
	"access_token_secret" => '',
	"icons" => '',
	"skin" => '',
	"top_bar" => '',
	"animation_type" => '',
	"background" => '',
	"background_map" => '',
	"footer_sidebar" => '',
	"ajax" => '',
	"google_api_code" => ''
);
$cascade_options = cascade_stripslashes_deep(array_merge($cascade_options, (array)get_option("cascade_options")));
	
//contact form options
global $cascade_contact_form_options;
$cascade_contact_form_options = array(
	"name_hint" => '',
	"email_hint" => '',
	"text_hint" => '',
	"email_subject" => '',
	"admin_name" => '',
	"admin_email" => '',
	"template" => '',
	"smtp_host" => '',
	"smtp_username" => '',
	"smtp_password" => '',
	"smtp_port" => '',
	"smtp_secure" => '',
	"name_error" => '',
	"email_error" => '',
	"text_error" => '',
	"message_send_error" => '',
	"message_send_ok" => '',
);
$cascade_contact_form_options = cascade_stripslashes_deep(array_merge($cascade_contact_form_options, get_option("cascade_contact_form_options")));

//get_links_config
function cascade_get_links_config($params = null)
{
	$result = array();
	//get pages
	query_posts(array( 
		/*'posts_per_page' => 4,
		'paged' => $params['cascade_page'],*/
		'posts_per_page' => -1,
		'post_type' => 'page',
		'post_status' => 'publish',
		'orderby' => 'menu_order',
		'order' => 'ASC',
		'meta_query' => array(
			'relation' => 'OR',
			array(
				'key' => '_wp_page_template',
				'compare' => '!=',
				'value' => 'template-full-width.php'
			),
			array(
				'key' => '_wp_page_template',
				'compare' => 'NOT EXISTS',
				'value' => 'template-full-width.php'
			)
		)
	));
	$i = 0;
	if(have_posts()) : while (have_posts()) : the_post();
		global $post;
		$result["link"][] = $post->post_name;
		$result["post_id"][] = get_the_ID();
		$result["active"][] = get_post_meta(get_the_ID(), "active", true);
		$i++;
	endwhile; endif;
	wp_reset_query();
	$result["lastPage"] = ceil($i/4);
	//get full width template pages
	query_posts(array(
		'posts_per_page' => -1,
		'post_type' => 'page',
		'post_status' => 'publish',
		'orderby' => 'menu_order',
		'order' => 'ASC',
		'meta_key' => '_wp_page_template',
		'meta_value' => 'template-full-width.php'
	));
	$result["link_full_width"] = array();
	if(have_posts()) : while (have_posts()) : the_post();
		global $post;
		$result["link_full_width"][] = $post->post_name;
		$result["fw_post_id"][] = get_the_ID();
		$result["fw_active"][] = get_post_meta(get_the_ID(), "active", true);
		$color = get_post_meta(get_the_ID(), "color", true);
		if($color=="")
			$color = "blue";
		$result["color"][] = $color;
	endwhile; endif;
	wp_reset_query();
	return $result;
}

function cascade_enqueue_scripts()
{
	global $cascade_options;
	//js
	wp_enqueue_script("jquery");
	wp_enqueue_script("jquery-ba-bqq", get_template_directory_uri() . "/js/jquery.ba-bqq.min.js", array("jquery"));
	wp_enqueue_script("jquery-easing", get_template_directory_uri() . "/js/jquery.easing.js", array("jquery"));
	wp_enqueue_script("jquery-captify", get_template_directory_uri() . "/js/jquery.captify.js", array("jquery"));
	wp_enqueue_script("jquery-block-ui", get_template_directory_uri() . "/js/jquery.blockUI.js", array("jquery"));
	wp_enqueue_script("jquery-bx-slider", get_template_directory_uri() . "/js/jquery.bxSlider.js", array("jquery"));
	wp_enqueue_script("jquery-qtip", get_template_directory_uri() . "/js/jquery.qtip.min.js", array("jquery"));
	wp_enqueue_script("jquery-fancybox", get_template_directory_uri() . "/js/jquery.fancybox.js", array("jquery"));
	wp_enqueue_script("jquery-mousewheel", get_template_directory_uri() . "/js/jquery.mousewheel.js", array("jquery"));
	wp_enqueue_script("jquery-jscrollpane", get_template_directory_uri() . "/js/jquery.jScrollPane.js", array("jquery"));
	wp_enqueue_script("jquery-nivo-slider", get_template_directory_uri() . "/js/jquery.nivo.slider.js", array("jquery"));
	wp_enqueue_script("jquery-isotope", get_template_directory_uri() . "/js/jquery.isotope-packed.js", array("jquery"));
	wp_enqueue_script("google-maps-v3", "//maps.google.com/maps/api/js" . ($cascade_options["google_api_code"]!="" ? "?key=" . esc_attr($cascade_options["google_api_code"]) : ""), false, array(), false, true);
	
	wp_enqueue_script("cascade-script", get_template_directory_uri() . "/js/script.js", array("jquery"));
    wp_enqueue_script("cascade-cascade", get_template_directory_uri() . "/js/cascade.js", array("jquery"));
	wp_enqueue_script("cascade-main", get_template_directory_uri() . "/js/main.js", array("jquery"));
	wp_enqueue_script("cascade-contact-form", get_template_directory_uri() . "/js/cascade_contact_form.js", array("jquery"));
	wp_enqueue_script("cascade-comment-form", get_template_directory_uri() . "/js/cascade_comment_form.js", array("jquery"));
	
	$data = cascade_get_links_config();
	
	//ajaxurl
	$data["ajaxurl"] = get_template_directory_uri() . "/cascade-ajax.php";
	$data["twitter_login"] = $cascade_options["twitter_login"];
	$data["twitts_number"] = $cascade_options["twitts_number"];
	$data["animation_type"] = $cascade_options["animation_type"];
	if((int)get_option("cascade_home")>0)
	{
		$home_page = get_post(get_option("cascade_home"));
		$data["home_page_link"] = $home_page->post_name;
	}
	//ajax
	$data["ajax"] = (int)$cascade_options["ajax"];
	$data["home_url"] = get_home_url();
	//pass data to javascript
	$params = array(
		'l10n_print_after' => 'config = ' . json_encode($data) . ';'
	);
	wp_localize_script("cascade-main", "config", $params);
	
	//css
	wp_enqueue_style("main-style", get_stylesheet_uri());
	wp_enqueue_style("jquery-captify", get_template_directory_uri() . "/style/jquery.captify.css");
	wp_enqueue_style("jquery-jscrollpane", get_template_directory_uri() . "/style/jquery.jScrollPane.css");
	wp_enqueue_style("jquery-qtip", get_template_directory_uri() . "/style/jquery.qtip.css");
	wp_enqueue_style("jquery-nivo-slider", get_template_directory_uri() . "/style/jquery.nivo-slider.css");
	wp_enqueue_style("jquery-fancybox", get_template_directory_uri() . "/style/fancybox/jquery.fancybox.css");
	wp_enqueue_style("google-font-open-sans", "//fonts.googleapis.com/css?family=Open+Sans:400,300");
	//disable top bar
	if($cascade_options["top_bar"]=="0")
		wp_enqueue_style("cascade-hide-top-bar", get_template_directory_uri() . "/style/cascade_hide_top_bar.css");
	wp_enqueue_style("cascade-custom-css", get_template_directory_uri() . "/style/custom_styles.css");
}
add_action("wp_enqueue_scripts", "cascade_enqueue_scripts");

//get cascade
function cascade_get($params)
{
	global $wpdb;
	
	$cascade_options = cascade_stripslashes_deep(get_option("cascade_options"));
	$result = array();
	
	//get number of pages
	query_posts(array( 
		'post_type' => 'page',
		'posts_per_page' => -1,
		'post_status' => 'publish',
		'orderby' => 'menu_order', 
		'order' => 'ASC',
		'meta_query' => array(
			'relation' => 'OR',
			array(
				'key' => '_wp_page_template',
				'compare' => '!=',
				'value' => 'template-full-width.php'
			),
			array(
				'key' => '_wp_page_template',
				'compare' => 'NOT EXISTS',
				'value' => 'template-full-width.php'
			)
		)
	));
	global $wp_query;
	$result["count"] = $wp_query->post_count;
	$result["lastPage"] = ceil($result["count"]/4);
	
	//get pages
	query_posts(array( 
		'post_type' => 'page',
		'posts_per_page' => 4,
		'post_status' => 'publish',
		'paged' => $params['cascade_page'],
		'orderby' => 'menu_order', 
		'order' => 'ASC',
		'meta_query' => array(
			'relation' => 'OR',
			array(
				'key' => '_wp_page_template',
				'compare' => '!=',
				'value' => 'template-full-width.php'
			),
			array(
				'key' => '_wp_page_template',
				'compare' => 'NOT EXISTS',
				'value' => 'template-full-width.php'
			)
		)
	));
	
	$i = 0;
	$result["html"] = "";
	if(have_posts()) : while (have_posts()) : the_post();
		global $post;
		$custom_url = get_post_meta(get_the_ID(), "custom_url", true);
		$color = get_post_meta(get_the_ID(), "color", true);
		if($color=="")
			$color = "blue";
		$icon = get_post_meta(get_the_ID(), "icon", true);
		if($icon=="")
			$icon = "info";
		
		$custom_tab_image_url = get_post_meta(get_the_ID(), "custom_tab_image_url", true);
		if($custom_tab_image_url!="")
			$background_image_url = $custom_tab_image_url;
		else	
			$background_image_url = get_template_directory_uri() . '/images/tabs/' . $color . '_' . $icon . '.png';
			
		$custom_tab_image_hover_url = get_post_meta(get_the_ID(), "custom_tab_image_hover_url", true);
		
		$result["html"] .= '
		<li id="cascade-portfolio-' .  esc_attr(get_the_ID()) . '" class="cascade-color-' . esc_attr($color) . ' cascade-tab-' . esc_attr($i+1) . '">
			' . ($custom_tab_image_hover_url!="" ? '
			<style type="text/css">
				.cascade-tab-hover-' . ($i+1) . ':hover, .cascade-active .cascade-tab-hover-' . ($i+1) . '
				{
					background-image: url("' . $custom_tab_image_hover_url . '") !important;
					background-position: 0 0 !important;
				}
				.cascade-tab-hover-' . ($i+1) . ':hover .cascade_line_horizontal, .cascade-active .cascade-tab-hover-' . ($i+1) . ' .cascade_line_horizontal
				{
					display: block !important;
				}
			</style>' : '' ) . '
			<a href="' . ($custom_url!="" ? esc_attr($custom_url) : ((int)$cascade_options['ajax'] ? '#!/' : '') . esc_attr($post->post_name)) . '" style="background-image: url(\'' . esc_url($background_image_url) . '\')" class="cascade-menu-link' . ($custom_tab_image_url!="" || $custom_tab_image_hover_url!="" ? ' cascade-disable-hover' : '') . ($custom_tab_image_hover_url!="" ? ' cascade-tab-hover-' . esc_attr($i+1) : '') . '">';
			if($custom_tab_image_url!="" || $custom_tab_image_hover_url!="")
				$result["html"] .= '<span class="cascade_line_horizontal' . ($custom_tab_image_url=="" ? ' cascade_hidden' : '') . '"></span>';
		$result["html"] .= '
			<span class="cascade_title">' . get_the_title() . '</span>';
			if($subtitle = get_post_meta(get_the_ID(), "subtitle", true))
				$result["html"] .= '<span class="cascade_subtitle">' . $subtitle . '</span>';
		$result["html"] .= '</a></li>';
		$i++;
	endwhile; endif;
	//Reset Query
	wp_reset_query();
	return $result;
}

//ajax
function cascade_get_content()
{
	$result = array();
	if($_GET["name"]!='')
	{
		//post
		query_posts("name=" . $_GET["name"] . "&post_type=post");
		if(have_posts()) : the_post();
			if($_GET["parent_name"]!="")
			{
				global $parent;
				$args=array(
				  'name' => $_GET["parent_name"],
				  'post_type' => 'page',
				  'post_status' => 'publish',
				  'showposts' => 1
				);
				$parentArray = get_posts($args);
				$parent = $parentArray[0];
			}
			$template = get_post_meta($parent->ID, '_wp_page_template', true);
			ob_start();
			if(isset($_GET["type"]) && $_GET["type"]=="get_comments")
				comments_template();
			else if($template=="blog-full.php")
				include("single-blog-full.php");
			else if($template=="blog-widget.php")
				include("single-blog-widget.php");
			$result["html"] = ob_get_contents();
			ob_end_clean();
		else:
			//page
			query_posts("name=" . $_GET["name"] . "&post_type=page");
			if(have_posts()) : the_post(); 
				$template = get_post_meta(get_the_ID(), '_wp_page_template', true);
				if($template!="" && $template!="default")
				{
					ob_start();
					$included = 1;
					include($template);
					$result["html"] = ob_get_contents();
					ob_end_clean();
				}
				else
				{
					ob_start();
					if(comments_open())
					{
						comments_template();
						require_once("comments-form.php");
					}
					$result["html"] = (function_exists("has_blocks") && has_blocks() ? '<div class="has-gutenberg-blocks">' : '') . do_shortcode(apply_filters('the_content', get_the_content())) . (function_exists("has_blocks") && has_blocks() ? '</div>' : '') . ob_get_contents();
					ob_end_clean();
				}
			endif;
		endif;
		//contact form 7
		if(defined('WPCF7_PLUGIN_DIR') && WPCF7_LOAD_JS)
			$result["cf7"] = plugins_url('scripts.js', WPCF7_PLUGIN_DIR . "/includes/js/scripts.js");
	}
	/*if((int)$_GET["id"])
	{
		$post = get_post($_GET["id"]);
		if($post->post_type=="post")
		{
			if((int)$_GET["parent_id"]>0)
			{
				global $parent;
				$parent = get_post($_GET["parent_id"]);
			}
			$template = get_post_meta($parent->ID, '_wp_page_template', true);
			ob_start();
			if($_GET["type"]=="get_comments")
			{
				query_posts("p=" . $post->ID . "&post_type=post");
				if(have_posts()) : the_post(); 
					comments_template();
				endif;
			}
			else if($template=="blog-full.php")
				include("single-blog-full.php");
			else if($template=="blog-widget.php")
				include("single-blog-widget.php");
			$result["html"] = ob_get_contents();
			ob_end_clean();
		}
		else
		{
			$template = get_post_meta($post->ID, '_wp_page_template', true);
			if($template!="" && $template!="default")
			{
				ob_start();
				include($template);
				$result["html"] = ob_get_contents();
				ob_end_clean();
			}
			else
				$result["html"] = do_shortcode(apply_filters("the_content", $post->post_content));
		}
		//contact form 7
		if(defined('WPCF7_PLUGIN_DIR') && WPCF7_LOAD_JS)
			$result["cf7"] = plugins_url('scripts.js', WPCF7_PLUGIN_DIR . "/includes/js/scripts.js");
	}*/
	echo @json_encode($result);
	exit();
}
add_action("wp_ajax_cascade_get_content", "cascade_get_content");
add_action("wp_ajax_nopriv_cascade_get_content", "cascade_get_content");

//pagination
function cascade_paging()
{
	$result = array();
	$isOk = true;
	if((int)$_GET["cascade_page"]>0)
	{
		//get cascade
		$params = array(
			"cascade_page" => (int)$_GET["cascade_page"]
		);
		$resultCascade = cascade_get($params);
		$result["html"] = $resultCascade["html"];
		$result["lastPage"] = $resultCascade["lastPage"];
		
		//get links config
		$result["links_config"] = cascade_get_links_config();
	}
	else
		$isOk = false;
	$result["isOk"] = $isOk;
	echo @json_encode($result);
	exit();
}
add_action("wp_ajax_cascade_paging", "cascade_paging");
add_action("wp_ajax_nopriv_cascade_paging", "cascade_paging");
?>