<?php
/*
Plugin Name: Cascade Theme Portfolio
Plugin URI: https://1.envato.market/quanticalabs-portfolio
Description: Cascade Theme Portfolio Plugin
Author: QuanticaLabs
Author URI: https://1.envato.market/quanticalabs-portfolio
Version: 1.0
Text Domain: cascade_portfolio
*/

//translation
function cascade_portfolio_load_textdomain()
{
	load_plugin_textdomain("cascade_portfolio", false, dirname(plugin_basename(__FILE__)) . '/languages');
}
add_action('plugins_loaded', 'cascade_portfolio_load_textdomain');
//custom post type - portfolio
function cascade_portfolio_init()
{  
	$labels = array(
		'name' => _x('Portfolio', 'post type general name', 'cascade_portfolio'),
		'singular_name' => _x('Portfolio Item', 'post type singular name', 'cascade_portfolio'),
		'add_new' => _x('Add New', 'cascade_portfolio', 'cascade_portfolio'),
		'add_new_item' => __('Add New Portfolio Item', 'cascade_portfolio'),
		'edit_item' => __('Edit Portfolio Item', 'cascade_portfolio'),
		'new_item' => __('New Portfolio Item', 'cascade_portfolio'),
		'all_items' => __('All Portfolio Items', 'cascade_portfolio'),
		'view_item' => __('View Portfolio Item', 'cascade_portfolio'),
		'search_items' => __('Search Portfolio Item', 'cascade_portfolio'),
		'not_found' =>  __('No portfolio items found', 'cascade_portfolio'),
		'not_found_in_trash' => __('No portfolio items found in Trash', 'cascade_portfolio'), 
		'parent_item_colon' => '',
		'menu_name' => __("Portfolio", 'cascade_portfolio')
	);
	$args = array(  
		"labels" => $labels, 
		"public" => true,  
		"show_ui" => true,  
		"capability_type" => "post",  
		"menu_position" => 20,
		"hierarchical" => false,  
		"rewrite" => true,  
		"supports" => array("title", "editor", "thumbnail", "page-attributes")  
	);
	register_post_type("cascade_portfolio", $args);  
	
	register_taxonomy("cascade_portfolio_category", array("cascade_portfolio"), array("label" => __("Categories", 'cascade_portfolio'), "singular_label" => __("Category", 'cascade_portfolio'), "rewrite" => true)); 
}  
add_action("init", "cascade_portfolio_init"); 

//Adds a box to the main column on the Portfolio edit screens
function cascade_add_portfolio_custom_box() 
{
    add_meta_box( 
        "portfolio_config",
        __("Options", 'cascade_portfolio'),
        "cascade_inner_portfolio_custom_box",
        "cascade_portfolio",
		"normal",
		"high"
    );
}
add_action("add_meta_boxes", "cascade_add_portfolio_custom_box");

// Prints the box content
function cascade_inner_portfolio_custom_box($post) 
{
	//Use nonce for verification
	wp_nonce_field(plugin_basename( __FILE__ ), "cascade_portfolio_noncename");

	//The actual fields for data entry
	$external_url_target = get_post_meta($post->ID, "external_url_target", true);
	echo '
	<table>
		<tr>
			<td>
				<label for="portfolio_video_url">' . __('Video URL (optional)', 'cascade_portfolio') . ':</label>
			</td>
			<td>
				<input class="regular-text" type="text" id="portfolio_video_url" name="portfolio_video_url" value="' . esc_attr(get_post_meta($post->ID, "video_url", true)) . '" />
				<span class="description">' . __("For Vimeo please use http://player.vimeo.com/video/%video_id% For YouTube: http://youtube.com/embed/%video_id%", 'cascade_portfolio') . '</span>
			</td>
		</tr>
		<tr>
			<td>
				<label for="portfolio_iframe_url">' . __('Ifame URL (optional)', 'cascade_portfolio') . ':</label>
			</td>
			<td>
				<input class="regular-text" type="text" id="portfolio_iframe_url" name="portfolio_iframe_url" value="' . esc_attr(get_post_meta($post->ID, "iframe_url", true)) . '" />
			</td>
		</tr>
		<tr>
			<td>
				<label for="portfolio_external_url">' . __('External URL (optional)', 'cascade_portfolio') . ':</label>
			</td>
			<td>
				<input class="regular-text" type="text" id="portfolio_external_url" name="portfolio_external_url" value="' . esc_attr(get_post_meta($post->ID, "external_url", true)) . '" />
			</td>
		</tr>
		<tr>
			<td>
				<label for="portfolio_external_url_target">' . __('External URL target', 'cascade_portfolio') . ':</label>
			</td>
			<td>
				<select id="portfolio_external_url_target" name="portfolio_external_url_target">
					<option value="same_window"' . ($external_url_target=="same_window" ? ' selected="selected"' : '') . '>' . __('same window', 'cascade_portfolio') . '</option>
					<option value="new_window"' . ($external_url_target=="new_window" ? ' selected="selected"' : '') . '>' . __('new window', 'cascade_portfolio') . '</option>
				</select>
			</td>
		</tr>
	</table>
	';
}

//When the post is saved, saves our custom data
function cascade_save_portfolio_postdata($post_id) 
{
	//verify if this is an auto save routine. 
	//if it is our form has not been submitted, so we dont want to do anything
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) 
		return;

	//verify this came from the our screen and with proper authorization,
	//because save_post can be triggered at other times
	if (!isset($_POST['cascade_portfolio_noncename']) || !wp_verify_nonce($_POST['cascade_portfolio_noncename'], plugin_basename( __FILE__ )))
		return;


	//Check permissions
	if(!current_user_can('edit_post', $post_id))
		return;

	//OK, we're authenticated: we need to find and save the data
	update_post_meta($post_id, "video_url", $_POST["portfolio_video_url"]);
	update_post_meta($post_id, "iframe_url", $_POST["portfolio_iframe_url"]);
	update_post_meta($post_id, "external_url", $_POST["portfolio_external_url"]);
	update_post_meta($post_id, "external_url_target", $_POST["portfolio_external_url_target"]);
}
add_action("save_post", "cascade_save_portfolio_postdata");

//custom portfolio items list
function cascade_portfolio_edit_columns($columns)
{  
	$columns = array(  
		"cb" => "<input type=\"checkbox\" />",  
		"title" => _x('Portfolio Item', 'post type singular name', 'cascade_portfolio'),   
		"video_url" => __('Video URL', 'cascade_portfolio'),
		"iframe_url" => __('Iframe URL', 'cascade_portfolio'),
		"external_url" => __('External URL', 'cascade_portfolio'),
		"cascade_portfolio_category" => __('Categories', 'cascade_portfolio'),
		"date" => __('Date', 'cascade_portfolio')
	);    

	return $columns;  
}  
add_filter("manage_edit-cascade_portfolio_columns", "cascade_portfolio_edit_columns");  

function manage_cascade_portfolio_posts_custom_column($column)
{
	global $post;
	switch ($column)  
	{
		case "video_url":   
			echo get_post_meta($post->ID, "video_url", true);  
			break;
		case "iframe_url":   
			echo get_post_meta($post->ID, "iframe_url", true);  
			break;
		case "external_url":   
			echo get_post_meta($post->ID, "external_url", true);  
			break;
		case "cascade_portfolio_category":
			echo get_the_term_list($post->ID, "cascade_portfolio_category", '', ', ',''); 
			break;
	}  
}
add_action("manage_cascade_portfolio_posts_custom_column", "manage_cascade_portfolio_posts_custom_column");

//portfolio
function cascade_portfolio_shortcode($atts)
{

	extract(shortcode_atts(array(
		"category" => "",
		"filtering" => 1
	), $atts));
	 
	//get pages
	query_posts(array( 
		'post_type' => 'cascade_portfolio',
		'posts_per_page' => '-1',
		'post_status' => 'publish',
		'cascade_portfolio_category' => $category,
		'orderby' => 'menu_order', 
		'order' => 'ASC'
	));
	
	$output='';
	if($filtering==1){ 
		$categories = array_values(array_filter(explode(',', $category)));
		$categories_count = count($categories); 
		$output .= '<ul class="no-list filter-list isotope_filters clear-fix">
				<li>
					<a class="selected" href="all-items"  title="' . __('All Items', 'cascade_portfolio') . '">' . __('All Items', 'cascade_portfolio') . '</a>
				</li>';
		for($i=0; $i<$categories_count; $i++)
		{
			$term = get_term_by('slug', $categories[$i], "cascade_portfolio_category");
			$output .= '<li>
					<a href="' . esc_attr(trim($categories[$i])) . '" title="' . esc_attr($term->name) . '">' . $term->name . '</a>
							</li>';
		}
		$output .= '</ul>';
	}
	$output .= "<ul class='no-list gallery-list overflow-fix clear-fix'>";
	
	if(have_posts()) : while (have_posts()) : the_post();
		if(has_post_thumbnail()) 
		{
			$video_url = get_post_meta(get_the_ID(), "video_url", true);
			if($video_url!="")
				$large_image_url = $video_url;
			else
			{
				$attachment_image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), "large");
				$large_image_url = $attachment_image[0];
			}
		
			$terms  = wp_get_post_terms( get_the_ID(), "cascade_portfolio_category" );
			$cat= "";
			for($i=0;$i<count($terms);++$i) 
				$cat.=" ".$terms[$i]->slug." "; 
			$external_url = get_post_meta(get_the_ID(), "external_url", true);
			$external_url_target = get_post_meta(get_the_ID(), "external_url_target", true);
			$iframe_url = get_post_meta(get_the_ID(), "iframe_url", true);
			$output .= "
			<li class='".esc_attr($cat) . ($external_url=="" ? " fancybox-" . ($video_url!="" ? "video" : ($iframe_url!="" ? "iframe" : "image")) . "'" : "") . "'>
				<a href='" . ($external_url=="" ? ($iframe_url!="" ? esc_url($iframe_url) : esc_url($large_image_url)) : esc_url($external_url)) . "'" . ($external_url!="" && $external_url_target=="new_window" ? " target='_blank'" : "") . " title='" . esc_attr(get_the_content()) . "'>"
				. get_the_post_thumbnail(get_the_ID(), "cascade-portfolio-thumb", array("alt" => get_the_title(), "title" => "")) .
				"</a>
			</li>";
		}
	endwhile; endif;
	$output .= "</ul>";
	return $output;
}
add_shortcode("cascade_portfolio", "cascade_portfolio_shortcode");
?>